"""Private constants used with tes-lib"""

EVENT_SOURCE_KEY = "event_source"
EVENT_TYPE_KEY = "event_type"
EVENT_ID_KEY = "event_id"
EVENT_STATE_KEY = "event_state"

NO_MATCHING_EVENT_FOUND = "No Matching Event Found"

DEFAULT_IP = "127.0.0.1"
DEFAULT_PORT = 8080

DEFAULT_REQUEST_TIMEOUT = 1
DEFAULT_POLL_INTERVAL = 0.1
DEFAULT_MAXIMUM_POLL_TIME = 1
DEFAULT_UNEXPECTED_EVENT_MAXIMUM_POLL_TIME = 1
